# coding=utf-8
from datetime import datetime
import json

from django.contrib.auth.decorators import login_required
from django.contrib.auth.models import Group
from django.db import transaction
from django.db.models.query_utils import Q
from django.http import HttpResponse, HttpResponseRedirect
from django.shortcuts import render_to_response
from django.template import RequestContext

from decorators import secure_module, last_access
from settings import PROFESORES_GROUP_ID, ADMINISTRATIVOS_GROUP_ID, ALUMNOS_GROUP_ID, EMAIL_INSTITUCIONAL_AUTOMATICO, EMAIL_DOMAIN, EMPLEADORES_GRUPO_ID, \
    ADMINISTRADOR_CORREO_GROUP_ID, TIPO_INSCRIPCION_REGULAR, TIPO_GRATUIDAD_TOTAL, PAIS_ECUADOR_ID
from sga.commonviews import adduserdata
from sga.forms import AdministrativosForm, GrupoUsuarioForm, NuevaInscripcionForm, SedeAdministrativoForm, \
    DocumentacionForm
from sga.funciones import MiPaginador, calculate_username, log, puede_realizar_accion_get, lista_correo, \
    generar_usuario, resetear_clave, url_back, bad_json, ok_json, generar_email, puede_realizar_accion_post, \
    generar_cambio_clave, generar_nombre
from sga.models import Persona, mi_institucion, Profesor, TiempoDedicacionDocente, Administrativo, Coordinacion, \
    Inscripcion, Documentacion


@login_required(redirect_field_name='ret', login_url='/login')
@secure_module
@last_access
@transaction.commit_on_success
def view(request):
    global ex
    data = {}
    adduserdata(request, data)
    persona = request.session['persona']
    if request.method == 'POST':
        action = request.POST['action']

        if action == 'add':
            try:
                form = AdministrativosForm(request.POST)
                if form.is_valid():
                    cedula = form.cleaned_data['cedula'].strip()
                    pasaporte = form.cleaned_data['pasaporte'].strip()
                    if not cedula and not pasaporte:
                        return bad_json(mensaje=u"Debe ingresar una identificación.")
                    if cedula:
                        if Persona.objects.filter(cedula=cedula).exists():
                            return bad_json(mensaje=u"Existe una persona registrada con esta identificación.")
                    if pasaporte:
                        if Persona.objects.filter(pasaporte=pasaporte).exists():
                            return bad_json(mensaje=u"Existe una persona registrada con esta identificación.")
                    personaadmin = Persona(nombres=form.cleaned_data['nombres'],
                                           apellido1=form.cleaned_data['apellido1'],
                                           apellido2=form.cleaned_data['apellido2'],
                                           cedula=cedula,
                                           pasaporte=pasaporte,
                                           nacimiento=form.cleaned_data['nacimiento'],
                                           sexo=form.cleaned_data['sexo'],
                                           pais=form.cleaned_data['pais'],
                                           nacionalidad=form.cleaned_data['nacionalidad'],
                                           provincianac=form.cleaned_data['provincianac'],
                                           cantonnac=form.cleaned_data['cantonnac'],
                                           parroquianac=form.cleaned_data['parroquianac'],
                                           provincianacselec=form.cleaned_data['provincianacselec'],
                                           cantonnacselec=form.cleaned_data['cantonnacselec'],
                                           parroquianacselec=form.cleaned_data['parroquianacselec'],
                                           provincia=form.cleaned_data['provincia'],
                                           canton=form.cleaned_data['canton'],
                                           parroquia=form.cleaned_data['parroquia'],
                                           sector=form.cleaned_data['sector'],
                                           direccion=form.cleaned_data['direccion'],
                                           direccion2=form.cleaned_data['direccion2'],
                                           num_direccion=form.cleaned_data['num_direccion'],
                                           telefono=form.cleaned_data['telefono'],
                                           telefono_conv=form.cleaned_data['telefono_conv'],
                                           sangre=form.cleaned_data['sangre'],
                                           email=form.cleaned_data['email'])
                    personaadmin.save(request)
                    administrativo = Administrativo(persona=personaadmin,
                                                    contrato='',
                                                    fechaingreso=datetime.now().date(),
                                                    activo=True)
                    administrativo.save(request)
                    username = calculate_username(personaadmin)
                    generar_usuario(personaadmin, username, ADMINISTRATIVOS_GROUP_ID)
                    if EMAIL_INSTITUCIONAL_AUTOMATICO:
                        personaadmin.emailinst = generar_email(personaadmin)
                    else:
                        personaadmin.emailinst = form.cleaned_data['emailinst']
                    personaadmin.save(request)
                    personaadmin.crear_perfil(administrativo=administrativo)
                    personaadmin.mi_ficha()
                    personaadmin.mi_perfil()
                    personaadmin.datos_extension()
                    from sga.tasks import send_html_mail
                    send_html_mail("Crear nueva cuenta de correo ", "emails/nuevacuentacorreo.html", {'persona': administrativo, 't': mi_institucion(), 'tipo_usuario': 'ESTUDIANTE'}, lista_correo([ADMINISTRADOR_CORREO_GROUP_ID]), [])
                    log(u'Adiciono personal administrativo: %s' % administrativo, request, "add")
                    return ok_json({"id": administrativo.id})
                else:
                    return bad_json(error=6)
            except Exception as ex:
                transaction.rollback()
                return bad_json(error=1)

        if action == 'edit':
            try:
                administrativo = Administrativo.objects.get(pk=request.POST['id'])
                personaadmin = administrativo.persona
                form = AdministrativosForm(request.POST)
                if form.is_valid():
                    cedula = form.cleaned_data['cedula'].strip()
                    pasaporte = form.cleaned_data['pasaporte'].strip()
                    if not cedula and not pasaporte:
                        return bad_json(mensaje=u"Debe ingresar una identificación.")
                    if cedula:
                        if Persona.objects.filter(cedula=cedula).exclude(id=personaadmin.id).exists():
                            return bad_json(mensaje=u"Existe una persona registrada con esta identificación.")
                    if pasaporte:
                        if Persona.objects.filter(pasaporte=pasaporte).exclude(id=personaadmin.id).exists():
                            return bad_json(mensaje=u"Existe una persona registrada con esta identificación.")
                    personaadmin.nombres = form.cleaned_data['nombres']
                    personaadmin.apellido1 = form.cleaned_data['apellido1']
                    personaadmin.apellido2 = form.cleaned_data['apellido2']
                    personaadmin.cedula = form.cleaned_data['cedula']
                    personaadmin.pasaporte = form.cleaned_data['pasaporte']
                    personaadmin.nacimiento = form.cleaned_data['nacimiento']
                    personaadmin.sexo = form.cleaned_data['sexo']
                    personaadmin.pais = form.cleaned_data['pais']
                    personaadmin.nacionalidad = form.cleaned_data['nacionalidad']
                    personaadmin.provincianac = form.cleaned_data['provincianac']
                    personaadmin.cantonnac = form.cleaned_data['cantonnac']
                    personaadmin.parroquianac = form.cleaned_data['parroquianac']
                    personaadmin.provincianacselec = form.cleaned_data['provincianacselec']
                    personaadmin.cantonnacselec = form.cleaned_data['cantonnacselec']
                    personaadmin.parroquianacselec = form.cleaned_data['parroquianacselec']
                    personaadmin.provincia = form.cleaned_data['provincia']
                    personaadmin.canton = form.cleaned_data['canton']
                    personaadmin.parroquia = form.cleaned_data['parroquia']
                    personaadmin.sector = form.cleaned_data['sector']
                    personaadmin.direccion = form.cleaned_data['direccion']
                    personaadmin.direccion2 = form.cleaned_data['direccion2']
                    personaadmin.num_direccion = form.cleaned_data['num_direccion']
                    personaadmin.telefono = form.cleaned_data['telefono']
                    personaadmin.telefono_conv = form.cleaned_data['telefono_conv']
                    personaadmin.email = form.cleaned_data['email']
                    personaadmin.emailinst = form.cleaned_data['emailinst']
                    personaadmin.sangre = form.cleaned_data['sangre']
                    personaadmin.save(request)
                    log(u'Modifico administrativo: %s' % administrativo, request, "edit")
                    return ok_json()
                else:
                    return bad_json(error=6)
            except Exception as ex:
                transaction.rollback()
                return bad_json(error=1)

        if action == 'resetear':
            try:
                from sga.tasks import send_html_mail
                administrativo = Administrativo.objects.get(pk=request.POST['id'])
                cambioclave = administrativo.persona.cambiar_clave()
                cambioclave.solicitada = True
                cambioclave.clavecambio = generar_cambio_clave()
                cambioclave.save(request)
                send_html_mail("Solicitud de cambio de clave.", "emails/cambioclave.html", {'fecha': datetime.now().date, 't': mi_institucion(), 'persona': administrativo.persona, 'clave': cambioclave.clavecambio}, administrativo.persona.lista_emails(), [])
                log(u'Reseteo clave de administrativo: %s' % administrativo, request, "add")
                return ok_json()
            except Exception as ex:
                transaction.rollback()
                return bad_json(error=1)

        if action == 'addprofesor':
            try:
                administrativo = Administrativo.objects.get(pk=request.POST['id'])
                if administrativo.persona.profesor_set.exists():
                    return bad_json(mensaje=u"El usuario ya tiene un perfil como profesor.")
                profesor = Profesor(persona=administrativo.persona,
                                    activo=True,
                                    coordinacion=request.session['coordinacionseleccionada'],
                                    fechaingreso=datetime.now().date(),
                                    dedicacion=TiempoDedicacionDocente.objects.all()[0])
                profesor.save(request)
                grupo = Group.objects.get(pk=PROFESORES_GROUP_ID)
                grupo.user_set.add(administrativo.persona.usuario)
                grupo.save()
                administrativo.persona.crear_perfil(profesor=profesor)
                log(u'Adiciono profesor: %s' % profesor, request, "add")
                return ok_json()
            except Exception as ex:
                transaction.rollback()
                return bad_json(error=1)

        if action == 'addestudiante':
            try:
                form = NuevaInscripcionForm(request.POST)
                if form.is_valid():
                    administrativo = Administrativo.objects.get(pk=int(request.POST['id']))
                    carrera = form.cleaned_data['carrera']
                    sesion = form.cleaned_data['sesion']
                    modalidad = form.cleaned_data['modalidad']
                    sede = form.cleaned_data['sede']
                    coordinacion = form.cleaned_data['coordinacion']
                    if Inscripcion.objects.filter(persona=administrativo.persona, carrera=carrera).exists():
                        return bad_json(mensaje=u"Ya se encuentra registrado en esa carrera.")
                    nuevainscripcion = Inscripcion(persona=administrativo.persona,
                                                   fecha=form.cleaned_data['fecha'],
                                                   fechainiciocarrera=form.cleaned_data['fechainiciocarrera'],
                                                   carrera=carrera,
                                                   modalidad=modalidad,
                                                   sesion=sesion,
                                                   sede=sede,
                                                   coordinacion=coordinacion,
                                                   condicionado=True,
                                                   tipoinscripcion_id=TIPO_INSCRIPCION_REGULAR,
                                                   tipogratuidad_id=TIPO_GRATUIDAD_TOTAL)
                    nuevainscripcion.save(request)
                    grupo = Group.objects.get(pk=ALUMNOS_GROUP_ID)
                    grupo.user_set.add(administrativo.persona.usuario)
                    grupo.save()
                    administrativo.persona.crear_perfil(inscripcion=nuevainscripcion)
                    minivel = nuevainscripcion.mi_nivel()
                    if form.cleaned_data['prenivelacion']:
                        nuevainscripcion.nivelhomologado = form.cleaned_data['nivelmalla']
                        nuevainscripcion.save(request)
                    nuevainscripcion.actualizar_nivel()
                    nuevainscripcion.actualiza_tipo_inscripcion()
                    nuevainscripcion.generar_rubro_inscripcion()
                    nuevainscripcion.mi_malla()
                    log(u'Adiciono como estudiante al administrativo: %s' % nuevainscripcion, request, "add")
                    documentos = nuevainscripcion.documentos_entregados()
                    documentos.titulo = form.cleaned_data['titulo']
                    documentos.acta = form.cleaned_data['acta']
                    documentos.cedula = form.cleaned_data['cedula2']
                    documentos.votacion = form.cleaned_data['votacion']
                    documentos.actaconv = form.cleaned_data['actaconv']
                    documentos.partida_nac = form.cleaned_data['partida_nac']
                    documentos.pre = form.cleaned_data['prenivelacion']
                    documentos.observaciones_pre = form.cleaned_data['observacionespre']
                    documentos.fotos = form.cleaned_data['fotos']
                    documentos.save(request)
                    # SNNA
                    snna = administrativo.persona.datos_snna()
                    snna.rindioexamen = form.cleaned_data['rindioexamen']
                    if snna.rindioexamen:
                        snna.fechaexamen = form.cleaned_data['fechaexamensnna']
                        snna.puntaje = form.cleaned_data['puntajesnna']
                    else:
                        snna.fechaexamen = None
                        snna.puntaje = 0
                    snna.save(request)
                    return ok_json({"id": nuevainscripcion.id})
                else:
                    raise
            except Exception as ex:
                transaction.rollback()
                return bad_json(error=1)

        if action == 'activar':
            try:
                administrativo = Administrativo.objects.get(pk=request.POST['id'])
                usuario = administrativo.persona.usuario
                usuario.is_active = True
                usuario.save()
                log(u'Activo usuario: %s' % administrativo, request, "edit")
                return ok_json()
            except Exception as ex:
                transaction.rollback()
                return bad_json(error=1)

        if action == 'activarperfil':
            try:
                administrativo = Administrativo.objects.get(pk=request.POST['id'])
                administrativo.activo = True
                administrativo.save(request)
                log(u'Activo perfil de usuario: %s' % administrativo, request, "edit")
                return ok_json()
            except Exception as ex:
                transaction.rollback()
                return bad_json(error=1)

        if action == 'desactivar':
            try:
                administrativo = Administrativo.objects.get(pk=request.POST['id'])
                ui = administrativo.persona.usuario
                ui.is_active = False
                ui.save()
                log(u'Desactivo usuario: %s' % administrativo, request, "edit")
                return ok_json()
            except Exception as ex:
                transaction.rollback()
                return bad_json(error=1)

        if action == 'desactivarperfil':
            try:
                administrativo = Administrativo.objects.get(pk=request.POST['id'])
                administrativo.activo = False
                administrativo.save(request)
                log(u'Desactivo perfil de usuario: %s' % administrativo, request, "edit")
                return ok_json()
            except Exception as ex:
                transaction.rollback()
                return bad_json(error=1)

        if action == 'addgrupo':
            try:
                administrativo = Administrativo.objects.get(pk=request.POST['id'])
                form = GrupoUsuarioForm(request.POST)
                if form.is_valid():
                    grupo = form.cleaned_data['grupo']
                    grupo.user_set.add(administrativo.persona.usuario)
                    grupo.save()
                    log(u'Adiciono grupo de usuarios: %s' % grupo, request, "add")
                    return ok_json()
                else:
                    return bad_json(error=6)
            except Exception as ex:
                transaction.rollback()
                return bad_json(error=1)

        if action == 'delgrupo':
            try:
                administrativo = Administrativo.objects.get(pk=request.POST['id'])
                grupo = Group.objects.get(pk=request.POST['idg'])
                if grupo.id in [PROFESORES_GROUP_ID, ALUMNOS_GROUP_ID, EMPLEADORES_GRUPO_ID]:
                    return bad_json(mensaje=u"No puede eliminar del grupo seleccionado.")
                if administrativo.persona.usuario.groups.exclude(id__in=[PROFESORES_GROUP_ID, ALUMNOS_GROUP_ID, EMPLEADORES_GRUPO_ID]).count() <= 1:
                    return bad_json(mensaje=u"El usuario debe de pertenecer a un grupo.")
                grupo.user_set.remove(administrativo.persona.usuario)
                grupo.save()
                log(u'Elimino de grupo de usuarios: %s' % grupo, request, "del")
                return ok_json()
            except Exception as ex:
                transaction.rollback()
                return bad_json(error=1)

        if action == 'asignarsede':
            try:
                if not puede_realizar_accion_post(request, 'sga.puede_modificar_administrativos'):
                    return bad_json(error=4)
                administrativo = Administrativo.objects.get(pk=request.POST['id'])
                form = SedeAdministrativoForm(request.POST)
                if form.is_valid():
                    administrativo.sede = form.cleaned_data['sede']
                    administrativo.save(request)
                    log(u'Modifico sede de administrativo: %s' % administrativo, request, "add")
                    return ok_json()
                else:
                    return bad_json(error=6)
            except Exception as ex:
                transaction.rollback()
                return bad_json(error=1)

        if action == 'adddocumentacion':
            try:
                form = DocumentacionForm(request.POST, request.FILES)
                if form.is_valid():
                    persona = Persona.objects.get(pk=int(request.POST['id']))
                    newfile = None
                    if 'archivo' in request.FILES:
                        newfile = request.FILES['archivo']
                        newfile._name = generar_nombre("documento_", newfile._name)
                    doc = Documentacion(persona=persona,
                                                  nombredocumento=form.cleaned_data['nombredocumento'],
                                                  identificador=form.cleaned_data['identificador'],
                                                  documento=newfile)
                    doc.save(request)
                    log(u'Adiciono documento %s' % doc, request, "adddocumento")
                    return ok_json()
                else:
                    return bad_json(error=6)
            except Exception as ex:
                transaction.rollback()
                return bad_json(error=1)

        if action == 'deldocumentacion':
            try:
                cert = Documentacion.objects.get(pk=request.POST['id'])
                cert.delete()
                log(u'Elimino Documento : %s' % cert, request, "deldocumentacion")
                return ok_json()
            except Exception as ex:
                transaction.rollback()
                return bad_json(error=2)

        if action == 'editdocumentacion':
            try:
                cert = Documentacion.objects.get(pk=request.POST['id'])
                form = DocumentacionForm(request.POST, request.FILES)
                if form.is_valid():
                    newfile = cert.documento
                    if 'archivo' in request.FILES:
                        newfile = request.FILES['archivo']
                        newfile._name = generar_nombre("certificado_", newfile._name)
                    cert.nombredocumento = form.cleaned_data['nombredocumento']
                    cert.identificador = form.cleaned_data['identificador']
                    cert.documento = newfile
                    cert.save(request)
                    log(u'Modificó Documento: %s' % cert, request, "edit")
                    return ok_json()
                else:
                    return bad_json(error=6)
            except Exception as ex:
                transaction.rollback()
                return bad_json(error=1)


        return bad_json(error=0)
    else:
        if 'action' in request.GET:
            action = request.GET['action']

            if action == 'add':
                try:
                    puede_realizar_accion_get(request, 'sga.puede_modificar_administrativos')
                    data['title'] = u'Adicionar personal administrativo'
                    form = AdministrativosForm(screenwidth=int(request.GET['screenwidth']),
                                               formbase='ajaxformdinamicbs.html')
                    form.adicionar()
                    form.adicionar_provincia()
                    data['email_domain'] = EMAIL_DOMAIN
                    data['form'] = form
                    data['pais_ecuador_id'] = PAIS_ECUADOR_ID
                    return render_to_response("administrativos/add.html", data, context_instance=RequestContext(request))
                except Exception as ex:
                    pass

            if action == 'desactivar':
                try:
                    puede_realizar_accion_get(request, 'sga.puede_modificar_administrativos')
                    data['title'] = u'Desactivar usuario'
                    data['administrativo'] = Administrativo.objects.get(pk=request.GET['id'])
                    return render_to_response("administrativos/desactivar.html", data, context_instance=RequestContext(request))
                except Exception as ex:
                    pass

            if action == 'desactivarperfil':
                try:
                    puede_realizar_accion_get(request, 'sga.puede_modificar_administrativos')
                    data['title'] = u'Desactivar perfil de usuario'
                    data['administrativo'] = Administrativo.objects.get(pk=request.GET['id'])
                    return render_to_response("administrativos/desactivarperfil.html", data, context_instance=RequestContext(request))
                except Exception as ex:
                    pass

            if action == 'activar':
                try:
                    puede_realizar_accion_get(request, 'sga.puede_modificar_administrativos')
                    data['title'] = u'Activar usuario'
                    data['administrativo'] = Administrativo.objects.get(pk=request.GET['id'])
                    return render_to_response("administrativos/activar.html", data, context_instance=RequestContext(request))
                except Exception as ex:
                    pass

            if action == 'activarperfil':
                try:
                    puede_realizar_accion_get(request, 'sga.puede_modificar_administrativos')
                    data['title'] = u'Activar perfil de usuario'
                    data['administrativo'] = Administrativo.objects.get(pk=request.GET['id'])
                    return render_to_response("administrativos/activarperfil.html", data, context_instance=RequestContext(request))
                except Exception as ex:
                    pass

            if action == 'edit':
                try:
                    puede_realizar_accion_get(request, 'sga.puede_modificar_administrativos')
                    data['title'] = u'Editar personal administrativo'
                    data['administrativo'] = administrativo = Administrativo.objects.get(pk=request.GET['id'])
                    personaadmin = administrativo.persona
                    form = AdministrativosForm(initial={'nombres': personaadmin.nombres,
                                                        'apellido1': personaadmin.apellido1,
                                                        'apellido2': personaadmin.apellido2,
                                                        'cedula': personaadmin.cedula,
                                                        'pasaporte': personaadmin.pasaporte,
                                                        'pais': personaadmin.pais,
                                                        'nacionalidad': personaadmin.nacionalidad,
                                                        'provincianac': personaadmin.provincianac,
                                                        'cantonnac': personaadmin.cantonnac,
                                                        'parroquianac': personaadmin.parroquianac,
                                                        'provincianacselec': personaadmin.provincianacselec,
                                                        'cantonnacselec': personaadmin.cantonnacselec,
                                                        'parroquianacselec': personaadmin.parroquianacselec,
                                                        'nacimiento': personaadmin.nacimiento,
                                                        'sexo': personaadmin.sexo,
                                                        'provincia': personaadmin.provincia,
                                                        'canton': personaadmin.canton,
                                                        'parroquia': personaadmin.parroquia,
                                                        'sector': personaadmin.sector,
                                                        'direccion': personaadmin.direccion,
                                                        'direccion2': personaadmin.direccion2,
                                                        'num_direccion': personaadmin.num_direccion,
                                                        'telefono': personaadmin.telefono,
                                                        'sangre': personaadmin.sangre,
                                                        'telefono_conv': personaadmin.telefono_conv,
                                                        'email': personaadmin.email,
                                                        'emailinst': personaadmin.emailinst},
                                               screenwidth=int(request.GET['screenwidth']),
                                               formbase='ajaxformdinamicbs.html')
                    form.editar(administrativo)
                    data['form'] = form
                    data['email_domain'] = EMAIL_DOMAIN
                    data['pais_ecuador_id'] = PAIS_ECUADOR_ID
                    data['paisselecc'] = personaadmin.pais.id if personaadmin.pais else 0
                    data['provincianac'] = personaadmin.provincianac if personaadmin.provincianac else 0
                    data['cantonnac'] = personaadmin.cantonnac if personaadmin.cantonnac else 0
                    data['parroquianac'] = personaadmin.parroquianac if personaadmin.parroquianac else 0
                    data['provincianacselec'] = personaadmin.provincianacselec.id if personaadmin.provincianacselec else 0
                    data['cantonnacselec'] = personaadmin.cantonnacselec.id if personaadmin.cantonnacselec else 0
                    data['parroquianacselec'] = personaadmin.parroquianacselec.id if personaadmin.parroquianacselec else 0
                    return render_to_response("administrativos/edit.html", data, context_instance=RequestContext(request))
                except Exception as ex:
                    pass

            if action == 'addgrupo':
                try:
                    puede_realizar_accion_get(request, 'sga.puede_modificar_administrativos')
                    data['title'] = u'Adicionar grupo'
                    data['administrativo'] = Administrativo.objects.get(pk=request.GET['id'])
                    form = GrupoUsuarioForm(formwidth=650,
                                            screenwidth=int(request.GET['screenwidth']),
                                            formbase='ajaxformdinamicbs.html')
                    form.grupos(Group.objects.all().exclude(id__in=[PROFESORES_GROUP_ID, ALUMNOS_GROUP_ID, EMPLEADORES_GRUPO_ID]).order_by('name'))
                    data['form'] = form
                    return render_to_response("administrativos/addgrupo.html", data, context_instance=RequestContext(request))
                except Exception as ex:
                    pass

            if action == 'resetear':
                try:
                    puede_realizar_accion_get(request, 'sga.puede_modificar_administrativos')
                    data['title'] = u'Resetear clave del usuario'
                    data['administrativo'] = Administrativo.objects.get(pk=request.GET['id'])
                    return render_to_response("administrativos/resetear.html", data, context_instance=RequestContext(request))
                except Exception as ex:
                    pass

            if action == 'addprofesor':
                try:
                    puede_realizar_accion_get(request, 'sga.puede_modificar_administrativos')
                    data['title'] = u'Crear cuenta de profesor'
                    data['administrativo'] = Administrativo.objects.get(pk=request.GET['id'])
                    return render_to_response("administrativos/addprofesor.html", data, context_instance=RequestContext(request))
                except Exception as ex:
                    pass

            if action == 'addestudiante':
                try:
                    puede_realizar_accion_get(request, 'sga.puede_modificar_administrativos')
                    data['title'] = u'Crear cuenta de estudiante'
                    data['administrativo'] = administrativo = Administrativo.objects.get(pk=request.GET['id'])
                    form = NuevaInscripcionForm(screenwidth=int(request.GET['screenwidth']),
                                                        formbase='ajaxformdinamicbs.html')
                    form.adicionar(administrativo.persona)
                    data['form'] = form
                    data['dominio'] = EMAIL_DOMAIN
                    return render_to_response("administrativos/addestudiante.html", data, context_instance=RequestContext(request))
                except Exception as ex:
                    pass

            if action == 'delgrupo':
                try:
                    puede_realizar_accion_get(request, 'sga.puede_modificar_administrativos')
                    data['title'] = u'Eliminar de grupo'
                    data['administrativo'] = Administrativo.objects.get(pk=request.GET['id'])
                    data['grupo'] = Group.objects.get(pk=request.GET['idg'])
                    return render_to_response("administrativos/delgrupo.html", data, context_instance=RequestContext(request))
                except Exception as ex:
                    pass

            if action == 'asignarsede':
                try:
                    data['title'] = u'Asignar sede'
                    data['administrativo'] = Administrativo.objects.get(pk=request.GET['id'])
                    data['form'] = SedeAdministrativoForm(formwidth=650,
                                                          screenwidth=int(request.GET['screenwidth']),
                                                          formbase='ajaxformdinamicbs.html')
                    return render_to_response("administrativos/asignarsede.html", data, context_instance=RequestContext(request))
                except Exception as ex:
                    pass

            if action == 'documentacion':
                try:
                    data['title'] = u'Lista de documentos'
                    data['atras'] = '/administrativos'
                    data['persona'] = persona = Persona.objects.get(pk=request.GET['id'])
                    data['bandera'] = 1
                    data['documentos'] = Documentacion.objects.filter(persona=persona)
                    return render_to_response("documentacion/listadocumentos.html", data, context_instance=RequestContext(request))
                except Exception as ex:
                    pass

            if action == 'adddocumentacion':
                try:
                    data['title'] = u'Adicionar Documento'
                    data['persona'] = persona = Persona.objects.get(pk=request.GET['id'])
                    data['formdestination'] = '/administrativos?action=documentacion&id='+str(persona.id)
                    data['form'] = DocumentacionForm(screenwidth=int(request.GET['screenwidth']),
                                                              formbase='ajaxformdinamicbs.html')
                    return render_to_response("documentacion/adddocumento.html", data,
                                              context_instance=RequestContext(request))
                except Exception as ex:
                    pass

            if action == 'deldocumentacion':
                try:
                    data['title'] = u'Borrar Documento'
                    data['doc'] = doc = Documentacion.objects.get(pk=request.GET['id'])
                    data['id'] = doc.id
                    return render_to_response("documentacion/deldocumento.html", data, context_instance=RequestContext(request))
                except Exception as ex:
                    pass

            if action == 'editdocumentacion':
                try:
                    data['title'] = u'Editar Documento'
                    data['documento'] = doc = Documentacion.objects.get(pk=request.GET['id'])
                    data['id'] = doc.id
                    data['form'] = DocumentacionForm(initial={'nombredocumento': doc.nombredocumento,
                                                                  'identificador': doc.identificador},
                                                         screenwidth=int(request.GET['screenwidth']),
                                                         formbase='ajaxformdinamicbs.html')
                    return render_to_response("documentacion/editdocumento.html", data, context_instance=RequestContext(request))
                except Exception as ex:
                    pass

            return url_back(request, ex=ex if 'ex' in locals() else None)
        else:
            try:
                data['title'] = u'Listado de personal administrativo'
                search = None
                ids = None
                if 's' in request.GET:
                    search = request.GET['s'].strip()
                    ss = search.split(' ')
                    if len(ss) == 1:
                        administrativos = Administrativo.objects.filter(Q(persona__nombres__icontains=search) |
                                                                        Q(persona__apellido1__icontains=search) |
                                                                        Q(persona__apellido2__icontains=search) |
                                                                        Q(persona__cedula__icontains=search) |
                                                                        Q(persona__pasaporte__icontains=search)).distinct()
                    else:
                        administrativos = Administrativo.objects.filter(Q(persona__apellido1__icontains=ss[0]) &
                                                                        Q(persona__apellido2__icontains=ss[1])).distinct()
                elif 'id' in request.GET:
                    ids = request.GET['id']
                    administrativos = Administrativo.objects.filter(id=ids).distinct()
                else:
                    administrativos = Administrativo.objects.all()
                paging = MiPaginador(administrativos, 25)
                p = 1
                try:
                    paginasesion = 1
                    if 'paginador' in request.session:
                        paginasesion = int(request.session['paginador'])
                    if 'page' in request.GET:
                        p = int(request.GET['page'])
                    else:
                        p = paginasesion
                    page = paging.page(p)
                except:
                    p = 1
                    page = paging.page(p)
                request.session['paginador'] = p
                data['paging'] = paging
                data['rangospaging'] = paging.rangos_paginado(p)
                data['page'] = page
                data['search'] = search if search else ""
                data['ids'] = ids if ids else ""
                data['administrativos'] = page.object_list
                data['grupo_docentes'] = PROFESORES_GROUP_ID
                data['grupo_empleadores'] = EMPLEADORES_GRUPO_ID
                data['grupo_estudiantes'] = ALUMNOS_GROUP_ID
                return render_to_response("administrativos/view.html", data, context_instance=RequestContext(request))
            except Exception as ex:
                return HttpResponseRedirect('/')