# coding=utf-8
from datetime import datetime

from django.contrib.auth.decorators import login_required
from django.contrib.auth.models import Group
from django.db import transaction
from django.db.models.query_utils import Q
from django.http import HttpResponseRedirect
from django.shortcuts import render_to_response
from django.template import RequestContext

from decorators import secure_module, last_access
from settings import PROFESORES_GROUP_ID, EMAIL_DOMAIN, \
    EMAIL_INSTITUCIONAL_AUTOMATICO, ALUMNOS_GROUP_ID, EMPLEADORES_GRUPO_ID, SISTEMAS_GROUP_ID, \
    ADMINISTRADOR_CORREO_GROUP_ID, ADMINISTRATIVOS_GROUP_ID, TIPO_GRATUIDAD_TOTAL, TIPO_INSCRIPCION_REGULAR, \
    PAIS_ECUADOR_ID, TIPO_DOCENTE_TEORIA, CLASES_HORARIO_ESTRICTO
from sga.commonviews import adduserdata, obtener_reporte
from sga.forms import ProfesorForm, CargarCVForm, CursoPersonaForm, \
    GrupoUsuarioForm, EstudioEducacionSuperiorForm, NuevaInscripcionForm, ArchivoEvidenciaEstudiosForm, \
    PublicacionPersonaForm, DocumentacionForm
from sga.funciones import MiPaginador, calculate_username, generar_nombre, log, puede_realizar_accion_get, lista_correo, \
    generar_usuario, url_back, resetear_clave, generar_email, generar_cambio_clave
from sga.funciones import bad_json, ok_json
from sga.models import Profesor, Persona, Clase, CVPersona, \
    mi_institucion, Administrativo, Materia, Turno, EstudioPersona, CursoPersona, Inscripcion, PublicacionPersona, \
    LeccionGrupo, ProfesorMateria, Sesion, Documentacion


@login_required(redirect_field_name='ret', login_url='/login')
@secure_module
@last_access
@transaction.commit_on_success
def view(request):
    global ex
    data = {}
    adduserdata(request, data)
    persona = request.session['persona']
    if request.method == 'POST':
        action = request.POST['action']

        if action == 'add':
            try:
                form = ProfesorForm(request.POST)
                if form.is_valid():
                    cedula = form.cleaned_data['cedula'].strip()
                    pasaporte = form.cleaned_data['pasaporte'].strip()
                    if not cedula and not pasaporte:
                        return bad_json(mensaje=u"Debe ingresar una identificación.")
                    if cedula:
                        if Persona.objects.filter(cedula=cedula).exists():
                            return bad_json(mensaje=u"Existe una persona registrada con esta identificación.")
                    if pasaporte:
                        if Persona.objects.filter(pasaporte=pasaporte).exists():
                            return bad_json(mensaje=u"Existe una persona registrada con esta identificación.")
                    personaprofesor = Persona(nombres=form.cleaned_data['nombres'],
                                              apellido1=form.cleaned_data['apellido1'],
                                              apellido2=form.cleaned_data['apellido2'],
                                              cedula=cedula,
                                              pasaporte=pasaporte,
                                              nacimiento=form.cleaned_data['nacimiento'],
                                              sexo=form.cleaned_data['sexo'],
                                              pais=form.cleaned_data['pais'],
                                              nacionalidad=form.cleaned_data['nacionalidad'],
                                              provincianac=form.cleaned_data['provincianac'],
                                              cantonnac=form.cleaned_data['cantonnac'],
                                              parroquianac=form.cleaned_data['parroquianac'],
                                              provincianacselec=form.cleaned_data['provincianacselec'],
                                              cantonnacselec=form.cleaned_data['cantonnacselec'],
                                              parroquianacselec=form.cleaned_data['parroquianacselec'],
                                              provincia=form.cleaned_data['provincia'],
                                              canton=form.cleaned_data['canton'],
                                              parroquia=form.cleaned_data['parroquia'],
                                              sector=form.cleaned_data['sector'],
                                              direccion=form.cleaned_data['direccion'],
                                              direccion2=form.cleaned_data['direccion2'],
                                              num_direccion=form.cleaned_data['num_direccion'],
                                              telefono=form.cleaned_data['telefono'],
                                              telefono_conv=form.cleaned_data['telefono_conv'],
                                              email=form.cleaned_data['email'],
                                              sangre=form.cleaned_data['sangre'])
                    personaprofesor.save(request)
                    username = calculate_username(personaprofesor)
                    generar_usuario(personaprofesor, username, PROFESORES_GROUP_ID)
                    if EMAIL_INSTITUCIONAL_AUTOMATICO:
                        personaprofesor.emailinst = generar_email(personaprofesor)
                    else:
                        personaprofesor.emailinst = form.cleaned_data['emailinst']
                    personaprofesor.save(request)
                    personaprofesor.datos_extension()
                    profesor = Profesor(persona=personaprofesor,
                                        activo=True,
                                        fechaingreso=form.cleaned_data['fechaingreso'],
                                        dedicacion=form.cleaned_data['dedicacion'],
                                        coordinacion=request.session['coordinacionseleccionada'],
                                        contrato=form.cleaned_data['contrato'])
                    profesor.save(request)
                    personaprofesor.crear_perfil(profesor=profesor)
                    personaprofesor.mi_ficha()
                    personaprofesor.mi_perfil()
                    personaprofesor.datos_extension()
                    from sga.tasks import send_html_mail
                    send_html_mail(u"Crear nueva cuenta de correo ", "emails/nuevacuentacorreo.html", {'persona': personaprofesor, 't': mi_institucion(), 'tipo_usuario': 'DOCENTE'}, lista_correo([ADMINISTRADOR_CORREO_GROUP_ID]), [])
                    log(u'Adiciono profesor: %s' % profesor, request, "add")
                    return ok_json({"id": profesor.id})
                else:
                    return bad_json(error=6)
            except Exception as d:
                transaction.rollback()
                return bad_json(error=1)

        if action == 'edit':
            try:
                profesor = Profesor.objects.get(pk=request.POST['id'])
                form = ProfesorForm(request.POST)
                persona = profesor.persona
                if form.is_valid():
                    cedula = form.cleaned_data['cedula'].strip()
                    pasaporte = form.cleaned_data['pasaporte'].strip()
                    if not cedula and not pasaporte:
                        return bad_json(mensaje=u"Debe ingresar una identificación.")
                    if cedula:
                        if Persona.objects.filter(cedula=cedula).exclude(id=persona.id).exists():
                            return bad_json(mensaje=u"Existe una persona registrada con esta identificación.")
                    if pasaporte:
                        if Persona.objects.filter(pasaporte=pasaporte).exclude(id=persona.id).exists():
                            return bad_json(mensaje=u"Existe una persona registrada con esta identificación.")
                    if not form.cleaned_data['laborando']:
                        if form.cleaned_data['fechafin'] <= form.cleaned_data['fechaingreso']:
                            return bad_json(mensaje=u"La fecha final no debe ser menor a la fecha de ingreso.")
                    persona.nombres = form.cleaned_data['nombres']
                    persona.apellido1 = form.cleaned_data['apellido1']
                    persona.apellido2 = form.cleaned_data['apellido2']
                    persona.cedula = form.cleaned_data['cedula']
                    persona.pasaporte = form.cleaned_data['pasaporte']
                    persona.nacimiento = form.cleaned_data['nacimiento']
                    persona.sexo = form.cleaned_data['sexo']
                    persona.pais = form.cleaned_data['pais']
                    persona.nacionalidad = form.cleaned_data['nacionalidad']
                    persona.provincianac = form.cleaned_data['provincianac']
                    persona.cantonnac = form.cleaned_data['cantonnac']
                    persona.parroquianac = form.cleaned_data['parroquianac']
                    persona.provincianacselec = form.cleaned_data['provincianacselec']
                    persona.cantonnacselec = form.cleaned_data['cantonnacselec']
                    persona.parroquianacselec = form.cleaned_data['parroquianacselec']
                    persona.provincia = form.cleaned_data['provincia']
                    persona.canton = form.cleaned_data['canton']
                    persona.parroquia = form.cleaned_data['parroquia']
                    persona.sector = form.cleaned_data['sector']
                    persona.direccion = form.cleaned_data['direccion']
                    persona.direccion2 = form.cleaned_data['direccion2']
                    persona.num_direccion = form.cleaned_data['num_direccion']
                    persona.telefono = form.cleaned_data['telefono']
                    persona.telefono_conv = form.cleaned_data['telefono_conv']
                    persona.email = form.cleaned_data['email']
                    persona.emailinst = form.cleaned_data['emailinst']
                    persona.sangre = form.cleaned_data['sangre']
                    persona.save(request)
                    profesor.fechaingreso = form.cleaned_data['fechaingreso']
                    profesor.laborando = form.cleaned_data['laborando']
                    profesor.fechafin = form.cleaned_data['fechafin']
                    profesor.dedicacion = form.cleaned_data['dedicacion']
                    profesor.contrato = form.cleaned_data['contrato']
                    profesor.coordinacion = form.cleaned_data['coordinacion']
                    profesor.save(request)
                    return ok_json()
                else:
                    return bad_json(error=6)
            except Exception as ex:
                transaction.rollback()
                return bad_json(error=1)

        if action == 'addtitulacion':
            try:
                profesor = Profesor.objects.get(pk=request.POST['id'])
                form = EstudioEducacionSuperiorForm(request.POST)
                if form.is_valid():
                    estudio = EstudioPersona(persona=profesor.persona,
                                             superior=True,
                                             institucioneducacionsuperior_id=form.cleaned_data['institucion'],
                                             carrera=form.cleaned_data['carrera'],
                                             niveltitulacion=form.cleaned_data['niveltitulacion'],
                                             detalleniveltitulacion=form.cleaned_data['detalleniveltitulacion'],
                                             titulo=form.cleaned_data['titulo'],
                                             fechainicio=form.cleaned_data['fechainicio'],
                                             fechafin=form.cleaned_data['fechafin'],
                                             fechagraduacion=form.cleaned_data['fechagraduacion'],
                                             registro=form.cleaned_data['registro'],
                                             cursando=form.cleaned_data['cursando'],
                                             cicloactual=form.cleaned_data['cicloactual'])
                    estudio.save(request)
                    log(u'Adiciono estudio: %s' % estudio, request, "add")
                    return ok_json()
                else:
                    return bad_json(error=6)
            except Exception as ex:
                transaction.rollback()
                return bad_json(error=1)

        if action == 'addcurso':
            try:
                profesor = Profesor.objects.get(pk=request.POST['id'])
                form = CursoPersonaForm(request.POST)
                if form.is_valid():
                    curso = CursoPersona(persona=profesor.persona,
                                         nombre=form.cleaned_data['nombre'],
                                         institucion_id=form.cleaned_data['institucion'],
                                         educacionsuperior=form.cleaned_data['esinstitucion'],
                                         institucionformacion=form.cleaned_data['institucionformacion'],
                                         tipocurso=form.cleaned_data['tipocurso'],
                                         fecha_inicio=form.cleaned_data['fecha_inicio'],
                                         apolloinstitucion=form.cleaned_data['apolloinstitucion'],
                                         fecha_fin=form.cleaned_data['fecha_fin'],
                                         horas=form.cleaned_data['horas'])
                    curso.save(request)
                    log(u'Adiciono curso: %s' % curso, request, "add")
                    return ok_json()
                else:
                    return bad_json(error=6)
            except Exception as ex:
                transaction.rollback()
                return bad_json(error=1)

        if action == 'edittitulacion':
            try:
                titulacion = EstudioPersona.objects.get(pk=request.POST['id'])
                form = EstudioEducacionSuperiorForm(request.POST)
                if form.is_valid():
                    titulacion.institucioneducacionsuperior_id = form.cleaned_data['institucion']
                    titulacion.niveltitulacion = form.cleaned_data['niveltitulacion']
                    titulacion.detalleniveltitulacion = form.cleaned_data['detalleniveltitulacion']
                    titulacion.carrera = form.cleaned_data['carrera']
                    titulacion.titulo = form.cleaned_data['titulo']
                    titulacion.fechainicio = form.cleaned_data['fechainicio']
                    titulacion.fechafin = form.cleaned_data['fechafin']
                    titulacion.fechagraduacion = form.cleaned_data['fechagraduacion']
                    titulacion.cursando = form.cleaned_data['cursando']
                    titulacion.cicloactual = form.cleaned_data['cicloactual']
                    titulacion.registro = form.cleaned_data['registro']
                    titulacion.save(request)
                    log(u'Modifico estudio: %s' % titulacion, request, "edit")
                    return ok_json()
                else:
                    return bad_json(error=6)
            except Exception as ex:
                transaction.rollback()
                return bad_json(error=1)

        if action == 'editcurso':
            try:
                curso = CursoPersona.objects.get(pk=request.POST['id'])
                form = CursoPersonaForm(request.POST)
                if form.is_valid():
                    esinstitucion = form.cleaned_data['esinstitucion']
                    curso.educacionsuperior = esinstitucion
                    curso.nombre = form.cleaned_data['nombre']
                    curso.institucion_id = int(form.cleaned_data['institucion']) if esinstitucion else None
                    curso.institucionformacion = form.cleaned_data['institucionformacion'] if not esinstitucion else ''
                    curso.tipocurso = form.cleaned_data['tipocurso']
                    curso.fecha_inicio = form.cleaned_data['fecha_inicio']
                    curso.fecha_fin = form.cleaned_data['fecha_fin']
                    curso.apolloinstitucion = form.cleaned_data['apolloinstitucion']
                    curso.horas = form.cleaned_data['horas']
                    curso.save(request)
                    log(u'modifico curso: %s' % curso, request, "edit")
                    return ok_json()
                else:
                    return bad_json(error=6)
            except Exception as ex:
                transaction.rollback()
                return bad_json(error=1)

        if action == 'deltitulacion':
            try:
                titulacion = EstudioPersona.objects.get(pk=request.POST['id'])
                log(u'Elimino estudio: %s' % titulacion, request, "del")
                titulacion.delete()
                return ok_json()
            except Exception as ex:
                transaction.rollback()
                return bad_json(error=2)

        if action == 'delcurso':
            try:
                curso = CursoPersona.objects.get(pk=request.POST['id'])
                log(u'Elimino curso: %s' % curso, request, "del")
                curso.delete()
                return ok_json()
            except Exception as ex:
                transaction.rollback()
                return bad_json(error=2)

        if action == 'cargarcv':
            try:
                profesor = Profesor.objects.get(pk=request.POST['id'])
                form = CargarCVForm(request.POST, request.FILES)
                if form.is_valid():
                    personaprofesor = profesor.persona
                    cv = personaprofesor.cv()
                    newfile = request.FILES['cv']
                    newfile._name = generar_nombre("cv_", newfile._name)
                    if cv:
                        cv.cv = newfile
                        cv.save(request)
                    else:
                        cv = CVPersona(persona=personaprofesor,
                                       cv=newfile)
                        cv.save(request)
                    return ok_json()
                else:
                    return bad_json(error=6)
            except Exception as ex:
                transaction.rollback()
                return bad_json(error=1)

        if action == 'resetear':
            try:
                from sga.tasks import send_html_mail
                profesor = Profesor.objects.get(pk=request.POST['id'])
                cambioclave = profesor.persona.cambiar_clave()
                cambioclave.solicitada = True
                cambioclave.clavecambio = generar_cambio_clave()
                cambioclave.save(request)
                send_html_mail("Solicitud de cambio de clave.", "emails/cambioclave.html", {'fecha': datetime.now().date, 't': mi_institucion(), 'persona': profesor.persona, 'clave': cambioclave.clavecambio}, profesor.persona.lista_emails(), [])
                log(u'Reseteo clave de profesor: %s' % profesor, request, "add")
                return ok_json()
            except Exception as ex:
                transaction.rollback()
                return bad_json(error=1)

        if action == 'borrarcv':
            try:
                profesor = Profesor.objects.get(pk=request.POST['id'])
                personaprofesor = profesor.persona
                personaprofesor.borrar_cv()
                return ok_json()
            except Exception as ex:
                transaction.rollback()
                return bad_json(error=1)

        if action == 'activar':
            try:
                profesor = Profesor.objects.get(pk=request.POST['id'])
                ui = profesor.persona.usuario
                ui.is_active = True
                ui.save()
                return ok_json()
            except Exception as ex:
                transaction.rollback()
                return bad_json(error=1)

        if action == 'desactivar':
            try:
                profesor = Profesor.objects.get(pk=request.POST['id'])
                ui = profesor.persona.usuario
                ui.is_active = False
                ui.save()
                return ok_json()
            except Exception as ex:
                transaction.rollback()
                return bad_json(error=1)

        if action == 'addadministrativo':
            try:
                profesor = Profesor.objects.get(pk=request.POST['id'])
                if profesor.persona.administrativo_set.exists():
                    return bad_json(mensaje=u"El usuario ya tiene un perfil como administrativo.")
                administrativo = Administrativo(persona=profesor.persona,
                                                fechaingreso=datetime.now().date(),
                                                activo=True)
                administrativo.save(request)
                grupo = Group.objects.get(pk=ADMINISTRATIVOS_GROUP_ID)
                grupo.user_set.add(profesor.persona.usuario)
                grupo.save()
                profesor.persona.crear_perfil(administrativo=administrativo)
                log(u'Adiciono administrativo: %s' % administrativo, request, "add")
                return ok_json()
            except Exception as ex:
                transaction.rollback()
                return bad_json(error=1)

        if action == 'addestudiante':
            try:
                form = NuevaInscripcionForm(request.POST)
                if form.is_valid():
                    profesor = Profesor.objects.get(pk=request.POST['id'])
                    carrera = form.cleaned_data['carrera']
                    sesion = form.cleaned_data['sesion']
                    modalidad = form.cleaned_data['modalidad']
                    sede = form.cleaned_data['sede']
                    coordinacion = form.cleaned_data['coordinacion']
                    if Inscripcion.objects.filter(persona=profesor.persona, carrera=carrera).exists():
                        return bad_json(mensaje=u"Ya se encuentra registrado en esa carrera.")
                    nuevainscripcion = Inscripcion(persona=profesor.persona,
                                                   fecha=form.cleaned_data['fecha'],
                                                   fechainiciocarrera=form.cleaned_data['fechainiciocarrera'],
                                                   fechafincarrera=form.cleaned_data['fechafincarrera'],
                                                   colegio='',
                                                   carrera=carrera,
                                                   modalidad=modalidad,
                                                   sesion=sesion,
                                                   sede=sede,
                                                   coordinacion=coordinacion,
                                                   condicionado=True,
                                                   tipoinscripcion_id=TIPO_INSCRIPCION_REGULAR,
                                                   tipogratuidad_id=TIPO_GRATUIDAD_TOTAL)
                    nuevainscripcion.save(request)
                    grupo = Group.objects.get(pk=ALUMNOS_GROUP_ID)
                    grupo.user_set.add(profesor.persona.usuario)
                    grupo.save()
                    profesor.persona.crear_perfil(inscripcion=nuevainscripcion)
                    minivel = nuevainscripcion.mi_nivel()
                    if form.cleaned_data['prenivelacion']:
                        nuevainscripcion.nivelhomologado = form.cleaned_data['nivelmalla']
                        nuevainscripcion.save(request)
                    nuevainscripcion.actualizar_nivel()
                    nuevainscripcion.actualiza_tipo_inscripcion()
                    nuevainscripcion.generar_rubro_inscripcion()
                    nuevainscripcion.mi_malla()
                    log(u'Adiciono como estudiante a docente: %s' % nuevainscripcion, request, "add")
                    documentos = nuevainscripcion.documentos_entregados()
                    documentos.titulo = form.cleaned_data['titulo']
                    documentos.acta = form.cleaned_data['acta']
                    documentos.cedula = form.cleaned_data['cedula2']
                    documentos.votacion = form.cleaned_data['votacion']
                    documentos.actaconv = form.cleaned_data['actaconv']
                    documentos.partida_nac = form.cleaned_data['partida_nac']
                    documentos.pre = form.cleaned_data['prenivelacion']
                    documentos.observaciones_pre = form.cleaned_data['observacionespre']
                    documentos.fotos = form.cleaned_data['fotos']
                    documentos.save(request)
                    # SNNA
                    snna = profesor.persona.datos_snna()
                    snna.rindioexamen = form.cleaned_data['rindioexamen']
                    if snna.rindioexamen:
                        snna.fechaexamen = form.cleaned_data['fechaexamensnna']
                        snna.puntaje = form.cleaned_data['puntajesnna']
                    else:
                        snna.fechaexamen = None
                        snna.puntaje = 0
                    snna.save(request)
                    return ok_json({"id": nuevainscripcion.id})
                else:
                    raise
            except Exception as ex:
                transaction.rollback()
                return bad_json(error=1)

        if action == 'desactivarperfil':
            try:
                profesor = Profesor.objects.get(pk=request.POST['id'])
                profesor.activo = False
                profesor.save(request)
                log(u'Desactivo perfil de usuario: %s' % profesor, request, "edit")
                return ok_json()
            except Exception as ex:
                transaction.rollback()
                return bad_json(error=1)

        if action == 'activarperfil':
            try:
                profesor = Profesor.objects.get(pk=request.POST['id'])
                profesor.activo = True
                profesor.save(request)
                log(u'Activo perfil de usuario: %s' % profesor, request, "edit")
                return ok_json()
            except Exception as ex:
                transaction.rollback()
                return bad_json(error=1)

        if action == 'verificartitulo':
            try:
                estudio = EstudioPersona.objects.get(pk=request.POST['id'])
                estudio.verificado = (request.POST['valor'] == 'true')
                estudio.save(request)
                log(u"Verifico datos de estudio: %s" % estudio, request, "edit")
                return ok_json()
            except Exception as ex:
                transaction.rollback()
                return bad_json(error=1)

        if action == 'verificarcurso':
            try:
                estudio = CursoPersona.objects.get(pk=request.POST['id'])
                estudio.verificado = (request.POST['valor'] == 'true')
                estudio.save(request)
                log(u"Verifico datos de curso: %s" % estudio, request, "edit")
                return ok_json()
            except Exception as ex:
                transaction.rollback()
                return bad_json(error=1)

        if action == 'verificarpublicacion':
            try:
                publicacion = PublicacionPersona.objects.get(pk=request.POST['id'])
                publicacion.verificado = (request.POST['valor'] == 'true')
                publicacion.save(request)
                log(u"Verifico datos de curso: %s" % publicacion, request, "edit")
                return ok_json()
            except Exception as ex:
                transaction.rollback()
                return bad_json(error=1)

        if action == 'addarchivo':
            try:
                form = ArchivoEvidenciaEstudiosForm(request.POST, request.FILES)
                if form.is_valid():
                    newfile = request.FILES['archivo']
                    newfile._name = generar_nombre("estudiopersona_", newfile._name)
                    estudio = EstudioPersona.objects.get(pk=request.POST['id'])
                    estudio.archivo = newfile
                    estudio.save(request)
                    log(u'Adiciono archivo: %s' % estudio, request, "add")
                    return ok_json()
                else:
                    return bad_json(error=6)
            except Exception as ex:
                transaction.rollback()
                return bad_json(error=1)

        if action == 'addarchivocurso':
            try:
                form = ArchivoEvidenciaEstudiosForm(request.POST, request.FILES)
                if form.is_valid():
                    newfile = request.FILES['archivo']
                    newfile._name = generar_nombre("cursopersona", newfile._name)
                    curso = CursoPersona.objects.get(pk=request.POST['id'])
                    curso.archivo = newfile
                    curso.save(request)
                    log(u'Adiciono archivo: %s' % curso, request, "add")
                    return ok_json()
                else:
                    return bad_json(error=6)
            except Exception as ex:
                transaction.rollback()
                return bad_json(error=1)

        if action == 'addarchivopublicacion':
            try:
                form = ArchivoEvidenciaEstudiosForm(request.POST, request.FILES)
                if form.is_valid():
                    newfile = request.FILES['archivo']
                    newfile._name = generar_nombre("cursopersona", newfile._name)
                    publicacion = PublicacionPersona.objects.get(pk=request.POST['id'])
                    publicacion.archivo = newfile
                    publicacion.save(request)
                    log(u'Adiciono archivo: %s' % publicacion, request, "add")
                    return ok_json()
                else:
                    return bad_json(error=6)
            except Exception as ex:
                transaction.rollback()
                return bad_json(error=1)

        if action == 'addpublicacion':
            try:
                profesor = Profesor.objects.get(pk=request.POST['id'])
                form = PublicacionPersonaForm(request.POST)
                if form.is_valid():
                    publicacion = PublicacionPersona(persona=profesor.persona,
                                                     nombre=form.cleaned_data['nombre'],
                                                     revista=form.cleaned_data['revista'],
                                                     fecha=form.cleaned_data['fecha'],
                                                     url=form.cleaned_data['url'],
                                                     isbn=form.cleaned_data['isbn'])
                    publicacion.save(request)
                    log(u'Adiciono curso: %s' % publicacion, request, "add")
                    return ok_json()
                else:
                    return bad_json(error=6)
            except Exception as ex:
                transaction.rollback()
                return bad_json(error=1)

        if action == 'editpublicacion':
            try:
                publicacion = PublicacionPersona.objects.get(pk=request.POST['id'])
                form = PublicacionPersonaForm(request.POST)
                if form.is_valid():
                    publicacion.nombre = form.cleaned_data['nombre']
                    publicacion.revista = form.cleaned_data['revista']
                    publicacion.fecha = form.cleaned_data['fecha']
                    publicacion.url = form.cleaned_data['url']
                    publicacion.isbn = form.cleaned_data['isbn']
                    publicacion.save(request)
                    log(u'modifico curso: %s' % publicacion, request, "edit")
                    return ok_json()
                else:
                    return bad_json(error=6)
            except Exception as ex:
                transaction.rollback()
                return bad_json(error=1)

        if action == 'delpublicacion':
            try:
                publicacion = PublicacionPersona.objects.get(pk=request.POST['id'])
                log(u'Elimino curso: %s' % publicacion, request, "del")
                publicacion.delete()
                return ok_json()
            except Exception as ex:
                transaction.rollback()
                return bad_json(error=2)

        if action == 'adddocumentacion':
            try:
                form = DocumentacionForm(request.POST, request.FILES)
                if form.is_valid():
                    persona = Persona.objects.get(pk=int(request.POST['id']))
                    newfile = None
                    if 'archivo' in request.FILES:
                        newfile = request.FILES['archivo']
                        newfile._name = generar_nombre("documento_", newfile._name)
                    doc = Documentacion(persona=persona,
                                                  nombredocumento=form.cleaned_data['nombredocumento'],
                                                  identificador=form.cleaned_data['identificador'],
                                                  documento=newfile)
                    doc.save(request)
                    log(u'Adiciono documento %s' % doc, request, "adddocumento")
                    return ok_json()
                else:
                    return bad_json(error=6)
            except Exception as ex:
                transaction.rollback()
                return bad_json(error=1)

        if action == 'deldocumentacion':
            try:
                cert = Documentacion.objects.get(pk=request.POST['id'])
                cert.delete()
                log(u'Elimino Documento : %s' % cert, request, "deldocumentacion")
                return ok_json()
            except Exception as ex:
                transaction.rollback()
                return bad_json(error=2)

        if action == 'editdocumentacion':
            try:
                cert = Documentacion.objects.get(pk=request.POST['id'])
                form = DocumentacionForm(request.POST, request.FILES)
                if form.is_valid():
                    newfile = cert.documento
                    if 'archivo' in request.FILES:
                        newfile = request.FILES['archivo']
                        newfile._name = generar_nombre("certificado_", newfile._name)
                    cert.nombredocumento = form.cleaned_data['nombredocumento']
                    cert.identificador = form.cleaned_data['identificador']
                    cert.documento = newfile
                    cert.save(request)
                    log(u'Modificó Documento: %s' % cert, request, "edit")
                    return ok_json()
                else:
                    return bad_json(error=6)
            except Exception as ex:
                transaction.rollback()
                return bad_json(error=1)


        return bad_json(error=0)
    else:
        if 'action' in request.GET:
            action = request.GET['action']

            if action == 'resetear':
                try:
                    puede_realizar_accion_get(request, 'sga.puede_modificar_profesores')
                    data['title'] = u'Resetear clave del usuario'
                    data['profesor'] = profesor = Profesor.objects.get(pk=request.GET['id'])
                    return render_to_response("docentes/resetear.html", data, context_instance=RequestContext(request))
                except Exception as ex:
                    pass

            if action == 'desactivar':
                try:
                    puede_realizar_accion_get(request, 'sga.puede_modificar_profesores')
                    data['profesor'] = profesor = Profesor.objects.get(pk=request.GET['id'])
                    return render_to_response("docentes/desactivar.html", data, context_instance=RequestContext(request))
                except Exception as ex:
                    pass

            if action == 'activar':
                try:
                    puede_realizar_accion_get(request, 'sga.puede_modificar_profesores')
                    data['profesor'] = profesor = Profesor.objects.get(pk=request.GET['id'])
                    return render_to_response("docentes/activar.html", data, context_instance=RequestContext(request))
                except Exception as ex:
                    pass

            if action == 'titulacion':
                try:
                    data['title'] = u'Titulos y cursos del profesor'
                    data['profesor'] = profesor = Profesor.objects.get(pk=request.GET['id'])
                    data['titulos'] = profesor.persona.estudiopersona_set.all()
                    data['cursos'] = profesor.persona.cursopersona_set.all()
                    data['publicaciones'] = profesor.persona.publicacionpersona_set.all()
                    return render_to_response("docentes/titulacion.html", data, context_instance=RequestContext(request))
                except Exception as ex:
                    pass

            if action == 'addtitulacion':
                try:
                    data['title'] = u'Adicionar titulación del profesor'
                    data['profesor'] = profesor = Profesor.objects.get(pk=request.GET['id'])
                    form = EstudioEducacionSuperiorForm(screenwidth=int(request.GET['screenwidth']),
                                                        formbase='ajaxformdinamicbs.html')
                    form.adicionar()
                    data['form'] = form
                    return render_to_response("docentes/addtitulacion.html", data, context_instance=RequestContext(request))
                except Exception as ex:
                    pass

            if action == 'addcurso':
                try:
                    puede_realizar_accion_get(request, 'sga.puede_modificar_profesores')
                    data['title'] = u'Adicionar curso'
                    data['profesor'] = profesor = Profesor.objects.get(pk=request.GET['id'])
                    data['form'] = CursoPersonaForm(screenwidth=int(request.GET['screenwidth']),
                                                    formbase='ajaxformdinamicbs.html')
                    return render_to_response("docentes/addcurso.html", data, context_instance=RequestContext(request))
                except Exception as ex:
                    pass

            if action == 'edittitulacion':
                try:
                    puede_realizar_accion_get(request, 'sga.puede_modificar_profesores')
                    data['title'] = u'Editar titulación del profesor'
                    data['titulacion'] = titulacion = EstudioPersona.objects.get(pk=request.GET['id'])
                    data['profesor'] = titulacion.persona.profesor()
                    form = EstudioEducacionSuperiorForm(initial={'institucion': titulacion.institucioneducacionsuperior_id,
                                                                 'niveltitulacion': titulacion.niveltitulacion,
                                                                 'detalleniveltitulacion': titulacion.detalleniveltitulacion,
                                                                 'carrera': titulacion.carrera,
                                                                 'fechainicio': titulacion.fechainicio,
                                                                 'fechafin': titulacion.fechafin,
                                                                 'cursando': titulacion.cursando,
                                                                 'cicloactual': titulacion.cicloactual,
                                                                 'titulo': titulacion.titulo,
                                                                 'fechagraduacion': titulacion.fechagraduacion,
                                                                 'registro': titulacion.registro},
                                                        screenwidth=int(request.GET['screenwidth']),
                                                        formbase='ajaxformdinamicbs.html')
                    form.editar(titulacion)
                    data['form'] = form
                    return render_to_response("docentes/edittitulacion.html", data, context_instance=RequestContext(request))
                except Exception as ex:
                    pass

            if action == 'editcurso':
                try:
                    data['title'] = u'Editar curso'
                    data['curso'] = curso = CursoPersona.objects.get(pk=request.GET['id'])
                    data['profesor'] = curso.persona.profesor()
                    form = CursoPersonaForm(initial={"institucion": curso.institucion.id if curso.institucion else None,
                                                     "esinstitucion": curso.educacionsuperior,
                                                     "institucionformacion": curso.institucionformacion,
                                                     "nombre": curso.nombre,
                                                     "tipocurso": curso.tipocurso,
                                                     "apolloinstitucion": curso.apolloinstitucion,
                                                     "fecha_inicio": curso.fecha_inicio,
                                                     "fecha_fin": curso.fecha_fin,
                                                     "horas": curso.horas},
                                            screenwidth=int(request.GET['screenwidth']),
                                            formbase='ajaxformdinamicbs.html')
                    form.editar(curso)
                    data['form'] = form
                    return render_to_response("docentes/editcurso.html", data, context_instance=RequestContext(request))
                except Exception as ex:
                    pass

            if action == 'deltitulacion':
                try:
                    puede_realizar_accion_get(request, 'sga.puede_modificar_profesores')
                    data['title'] = u'Borrar titulación del profesor'
                    data['titulacion'] = titulacion = EstudioPersona.objects.get(pk=request.GET['id'])
                    data['profesor'] = titulacion.persona.profesor()
                    return render_to_response("docentes/deltitulacion.html", data, context_instance=RequestContext(request))
                except Exception as ex:
                    pass

            if action == 'delcurso':
                try:
                    puede_realizar_accion_get(request, 'sga.puede_modificar_profesores')
                    data['title'] = u'Borrar curso'
                    data['curso'] = curso = CursoPersona.objects.get(pk=request.GET['id'])
                    data['profesor'] = curso.persona.profesor()
                    return render_to_response("docentes/delcurso.html", data, context_instance=RequestContext(request))
                except Exception as ex:
                    pass

            if action == 'add':
                try:
                    puede_realizar_accion_get(request, 'sga.puede_modificar_profesores')
                    data['title'] = u'Adicionar profesor'
                    form = ProfesorForm(screenwidth=int(request.GET['screenwidth']),
                                        formbase='ajaxformdinamicbs.html')
                    if EMAIL_INSTITUCIONAL_AUTOMATICO:
                        form.emailautomatico()
                    form.adicionar()
                    data['form'] = form
                    data['email_domain'] = EMAIL_DOMAIN
                    data['pais_ecuador_id'] = PAIS_ECUADOR_ID
                    return render_to_response("docentes/add.html", data, context_instance=RequestContext(request))
                except Exception as ex:
                    pass

            if action == 'edit':
                try:
                    puede_realizar_accion_get(request, 'sga.puede_modificar_profesores')
                    data['title'] = u'Editar profesor'
                    data['profesor'] = profesor = Profesor.objects.get(pk=request.GET['id'])
                    form = ProfesorForm(initial={'nombres': profesor.persona.nombres,
                                                 'apellido1': profesor.persona.apellido1,
                                                 'apellido2': profesor.persona.apellido2,
                                                 'cedula': profesor.persona.cedula,
                                                 'pasaporte': profesor.persona.pasaporte,
                                                 'pais': profesor.persona.pais,
                                                 'nacionalidad': profesor.persona.nacionalidad,
                                                 'provincianac': profesor.persona.provincianac,
                                                 'cantonnac': profesor.persona.cantonnac,
                                                 'parroquianac': profesor.persona.parroquianac,
                                                 'provincianacselec': profesor.persona.provincianacselec,
                                                 'cantonnacselec': profesor.persona.cantonnacselec,
                                                 'parroquianacselec': profesor.persona.parroquianacselec,
                                                 'nacimiento': profesor.persona.nacimiento,
                                                 'sexo': profesor.persona.sexo,
                                                 'sangre': profesor.persona.sangre,
                                                 'provincia': profesor.persona.provincia,
                                                 'canton': profesor.persona.canton,
                                                 'parroquia': profesor.persona.parroquia,
                                                 'sector': profesor.persona.sector,
                                                 'direccion': profesor.persona.direccion,
                                                 'direccion2': profesor.persona.direccion2,
                                                 'num_direccion': profesor.persona.num_direccion,
                                                 'telefono': profesor.persona.telefono,
                                                 'telefono_conv': profesor.persona.telefono_conv,
                                                 'email': profesor.persona.email,
                                                 'emailinst': profesor.persona.emailinst,
                                                 'coordinacion': profesor.coordinacion,
                                                 'dedicacion': profesor.dedicacion,
                                                 'fechaingreso': profesor.fechaingreso,
                                                 'fechafin': profesor.fechafin,
                                                 'laborando': profesor.laborando,
                                                 'contrato': profesor.contrato},
                                        screenwidth=int(request.GET['screenwidth']),
                                        formbase='ajaxformdinamicbs.html')
                    form.editar(profesor)
                    data['form'] = form
                    data['email_domain'] = EMAIL_DOMAIN
                    data['pais_ecuador_id'] = PAIS_ECUADOR_ID
                    return render_to_response("docentes/edit.html", data, context_instance=RequestContext(request))
                except Exception as ex:
                    pass

            if action == 'cargarcv':
                try:
                    puede_realizar_accion_get(request, 'sga.puede_modificar_profesores')
                    data['profesor'] = Profesor.objects.get(pk=request.GET['id'])
                    data['form'] = CargarCVForm(formwidth=650,
                                                screenwidth=int(request.GET['screenwidth']),
                                                formbase='ajaxformdinamicbs.html')
                    return render_to_response("docentes/cargarcv.html", data, context_instance=RequestContext(request))
                except Exception as ex:
                    pass

            if action == 'borrarcv':
                try:
                    puede_realizar_accion_get(request, 'sga.puede_modificar_profesores')
                    data['title'] = u'Borrar CV'
                    data['profesor'] = profesor = Profesor.objects.get(pk=request.GET['id'])
                    return render_to_response("docentes/borrarcv.html", data, context_instance=RequestContext(request))
                except Exception as ex:
                    pass

            if action == 'horario':
                try:
                    data['title'] = u'Horario de profesor'
                    data['profesor'] = profesor = Profesor.objects.get(pk=request.GET['id'])
                    clasesabiertas = LeccionGrupo.objects.filter(profesor=profesor, abierta=True).order_by('-fecha','-horaentrada')
                    hoy = datetime.now().date()
                    data['disponible'] = clasesabiertas.count() == 0
                    if clasesabiertas:
                        data['claseabierta'] = clasesabiertas[0]
                    if not data['disponible']:
                        if clasesabiertas.count() > 1:
                            for clase in clasesabiertas[1:]:
                                clase.abierta = False
                                clase.save(request)
                        data['lecciongrupo'] = LeccionGrupo.objects.filter(profesor=profesor, abierta=True)[0]
                    data['semana'] = [[1, 'Lunes'], [2, 'Martes'], [3, 'Miercoles'], [4, 'Jueves'], [5, 'Viernes'], [6, 'Sabado'], [7, 'Domingo']]
                    if CLASES_HORARIO_ESTRICTO:
                        data['materiasnoprogramadas'] = ProfesorMateria.objects.filter(materia__cerrado=False, profesor=profesor, hasta__gt=hoy, tipoprofesor__id=TIPO_DOCENTE_TEORIA, principal=True).exclude(materia__clase__id__isnull=False)
                        data['misclases'] = clases = Clase.objects.filter(activo=True, fin__gte=hoy, materia__profesormateria__profesor=profesor).order_by('inicio')
                    else:
                        data['materiasnoprogramadas'] = ProfesorMateria.objects.filter(materia__cerrado=False, profesor=profesor, tipoprofesor__id=TIPO_DOCENTE_TEORIA, principal=True).exclude(materia__clase__id__isnull=False)
                        data['misclases'] = clases = Clase.objects.filter(Q(materia__profesormateria__profesor=profesor) | Q(materiacurso__profesor=profesor), activo=True, fin__gte=hoy).order_by('inicio')
                    data['fecha'] = datetime.now().date()
                    data['reporte_3'] = obtener_reporte('horario_profesor')
                    return render_to_response("docentes/horario.html", data, context_instance=RequestContext(request))
                except Exception as ex:
                    pass

            if action == 'addadministrativo':
                try:
                    puede_realizar_accion_get(request, 'sga.puede_modificar_administrativos')
                    data['title'] = u'Crear cuenta de profesor'
                    data['profesor'] = Profesor.objects.get(pk=request.GET['id'])
                    return render_to_response("docentes/addadministrativo.html", data, context_instance=RequestContext(request))
                except Exception as ex:
                    pass

            if action == 'addestudiante':
                try:
                    puede_realizar_accion_get(request, 'sga.puede_modificar_administrativos')
                    data['title'] = u'Crear cuenta de estudiante'
                    data['profesor'] = profesor = Profesor.objects.get(pk=request.GET['id'])
                    form = NuevaInscripcionForm(screenwidth=int(request.GET['screenwidth']),
                                                        formbase='ajaxformdinamicbs.html')
                    form.adicionar(profesor.persona)
                    data['form'] = form
                    data['dominio'] = EMAIL_DOMAIN
                    return render_to_response("docentes/addestudiante.html", data, context_instance=RequestContext(request))
                except Exception as ex:
                    pass

            if action == 'desactivarperfil':
                try:
                    puede_realizar_accion_get(request, 'sga.puede_modificar_administrativos')
                    data['title'] = u'Desactivar perfil de usuario'
                    data['profesor'] = Profesor.objects.get(pk=request.GET['id'])
                    return render_to_response("docentes/desactivarperfil.html", data, context_instance=RequestContext(request))
                except Exception as ex:
                    pass

            if action == 'activarperfil':
                try:
                    puede_realizar_accion_get(request, 'sga.puede_modificar_administrativos')
                    data['title'] = u'Activar perfil de usuario'
                    data['profesor'] = Profesor.objects.get(pk=request.GET['id'])
                    return render_to_response("docentes/activarperfil.html", data, context_instance=RequestContext(request))
                except Exception as ex:
                    pass

            if action == 'materias':
                try:
                    data['title'] = u'Materias del profesor'
                    data['profesor'] = profesor = Profesor.objects.get(pk=request.GET['id'])
                    periodo = request.session['periodo']
                    data['materias'] = profesor.mis_materias(periodo).order_by('materia__asignatura__nombre')
                    data['reporte_0'] = obtener_reporte('listado_asistencia_dias')
                    data['reporte_1'] = obtener_reporte('lista_alumnos_matriculados_materia')
                    data['reporte_2'] = obtener_reporte("control_academico")
                    return render_to_response("docentes/materias.html", data, context_instance=RequestContext(request))
                except Exception as ex:
                    pass

            if action == 'addpublicacion':
                try:
                    puede_realizar_accion_get(request, 'sga.puede_modificar_profesores')
                    data['title'] = u'Adicionar publicación'
                    data['profesor'] = profesor = Profesor.objects.get(pk=request.GET['id'])
                    data['form'] = PublicacionPersonaForm(screenwidth=int(request.GET['screenwidth']),
                                                          formbase='ajaxformdinamicbs.html')
                    return render_to_response("docentes/addpublicacion.html", data, context_instance=RequestContext(request))
                except Exception as ex:
                    pass

            if action == 'addarchivo':
                try:
                    data['title'] = u'Adicionar archivo'
                    data['titulacion'] = titulacion = EstudioPersona.objects.get(pk=request.GET['id'])
                    data['profesor'] = titulacion.persona.profesor()
                    data['form'] = ArchivoEvidenciaEstudiosForm(screenwidth=int(request.GET['screenwidth']),
                                                                formbase='ajaxformdinamicbs.html')
                    return render_to_response("docentes/addarchivo.html", data, context_instance=RequestContext(request))
                except Exception as ex:
                    pass

            if action == 'addarchivopublicacion':
                try:
                    data['title'] = u'Adicionar archivo'
                    data['publicacion'] = publicacion = PublicacionPersona.objects.get(pk=request.GET['id'])
                    data['profesor'] = publicacion.persona.profesor()
                    data['form'] = ArchivoEvidenciaEstudiosForm(screenwidth=int(request.GET['screenwidth']),
                                                                formbase='ajaxformdinamicbs.html')
                    return render_to_response("docentes/addarchivopublicacion.html", data, context_instance=RequestContext(request))
                except Exception as ex:
                    pass

            if action == 'addarchivocurso':
                try:
                    data['title'] = u'Adicionar archivo'
                    data['curso'] = curso = CursoPersona.objects.get(pk=request.GET['id'])
                    data['profesor'] = curso.persona.profesor()
                    data['form'] = ArchivoEvidenciaEstudiosForm(screenwidth=int(request.GET['screenwidth']),
                                                                formbase='ajaxformdinamicbs.html')
                    return render_to_response("docentes/addarchivocurso.html", data, context_instance=RequestContext(request))
                except Exception as ex:
                    pass

            if action == 'editpublicacion':
                try:
                    puede_realizar_accion_get(request, 'sga.puede_modificar_profesores')
                    data['title'] = u'Editar publicación'
                    data['publicacion'] = publicacion = PublicacionPersona.objects.get(pk=request.GET['id'])
                    data['profesor'] = publicacion.persona.profesor()
                    data['form'] = form = PublicacionPersonaForm(initial={"nombre": publicacion.nombre,
                                                                          "revista": publicacion.revista,
                                                                          "fecha": publicacion.fecha,
                                                                          "url": publicacion.url,
                                                                          "isbn": publicacion.isbn}, formbase='ajaxformdinamicbs.html')
                    return render_to_response("docentes/editpublicacion.html", data, context_instance=RequestContext(request))
                except Exception as ex:
                    pass

            if action == 'delpublicacion':
                try:
                    puede_realizar_accion_get(request, 'sga.puede_modificar_profesores')
                    data['title'] = u'Borrar publicación'
                    data['publicacion'] = publicacion = PublicacionPersona.objects.get(pk=request.GET['id'])
                    data['profesor'] = publicacion.persona.profesor()
                    return render_to_response("docentes/delpublicacion.html", data,
                                              context_instance=RequestContext(request))
                except Exception as ex:
                    pass

            if action == 'documentacion':
                try:
                    data['title'] = u'Lista de documentos'
                    data['atras'] = '/docentes'
                    data['persona'] = persona = Persona.objects.get(pk=request.GET['id'])
                    data['bandera'] = 2
                    data['documentos'] = Documentacion.objects.filter(persona=persona)
                    return render_to_response("documentacion/listadocumentos.html", data, context_instance=RequestContext(request))
                except Exception as ex:
                    pass

            if action == 'adddocumentacion':
                try:
                    data['title'] = u'Adicionar Documento'
                    data['persona'] = persona = Persona.objects.get(pk=request.GET['id'])
                    data['formdestination'] = '/docentes?action=documentacion&id='+str(persona.id)
                    data['form'] = DocumentacionForm(screenwidth=int(request.GET['screenwidth']),
                                                              formbase='ajaxformdinamicbs.html')
                    return render_to_response("documentacion/adddocumento.html", data,
                                              context_instance=RequestContext(request))
                except Exception as ex:
                    pass

            if action == 'deldocumentacion':
                try:
                    data['title'] = u'Borrar Documento'
                    data['doc'] = doc = Documentacion.objects.get(pk=request.GET['id'])
                    data['id'] = doc.id
                    return render_to_response("documentacion/deldocumento.html", data, context_instance=RequestContext(request))
                except Exception as ex:
                    pass

            if action == 'editdocumentacion':
                try:
                    data['title'] = u'Editar Documento'
                    data['documento'] = doc = Documentacion.objects.get(pk=request.GET['id'])
                    data['id'] = doc.id
                    data['form'] = DocumentacionForm(initial={'nombredocumento': doc.nombredocumento,
                                                                  'identificador': doc.identificador},
                                                         screenwidth=int(request.GET['screenwidth']),
                                                         formbase='ajaxformdinamicbs.html')
                    return render_to_response("documentacion/editdocumento.html", data, context_instance=RequestContext(request))
                except Exception as ex:
                    pass

            return url_back(request, ex=ex if 'ex' in locals() else None)
        else:
            try:
                data['title'] = u'Listado de profesores'
                search = None
                ids = None
                if 's' in request.GET:
                    search = request.GET['s']
                    ss = search.split(' ')
                    if len(ss) == 1:
                        profesores = Profesor.objects.filter(Q(persona__nombres__icontains=search) |
                                                             Q(persona__apellido1__icontains=search) |
                                                             Q(persona__apellido2__icontains=search) |
                                                             Q(persona__cedula__icontains=search) |
                                                             Q(persona__pasaporte__icontains=search), coordinacion=data['coordinacionseleccionada']).distinct()
                    else:
                        profesores = Profesor.objects.filter(Q(persona__apellido1__icontains=ss[0]) &
                                                             Q(persona__apellido2__icontains=ss[1]), coordinacion=data['coordinacionseleccionada']).distinct()
                elif 'id' in request.GET:
                    ids = request.GET['id']
                    profesores = Profesor.objects.filter(id=ids, coordinacion=data['coordinacionseleccionada'])
                else:
                    profesores = Profesor.objects.filter(coordinacion=data['coordinacionseleccionada'])
                paging = MiPaginador(profesores, 25)
                p = 1
                try:
                    paginasesion = 1
                    if 'paginador' in request.session:
                        paginasesion = int(request.session['paginador'])
                    if 'page' in request.GET:
                        p = int(request.GET['page'])
                    else:
                        p = paginasesion
                    page = paging.page(p)
                except:
                    p = 1
                    page = paging.page(p)
                request.session['paginador'] = p
                data['paging'] = paging
                data['rangospaging'] = paging.rangos_paginado(p)
                data['page'] = page
                data['search'] = search if search else ""
                data['ids'] = ids if ids else ""
                data['profesores'] = page.object_list
                data['reporte_0'] = obtener_reporte('listado_clases_abiertas')
                data['reporte_1'] = obtener_reporte('ficha_docente')
                return render_to_response("docentes/view.html", data, context_instance=RequestContext(request))
            except Exception as ex:
                return HttpResponseRedirect('/')